@@ -1,6 +1,5 @@
 use warnings;
 use strict;
-use Date::Manip ();
 
 package Jifty::Action::Record;
 
@@ -41,7 +40,11 @@ the constructor.
 
 sub record_class {
     my $self = shift;
-    $self->log->fatal("Jifty::Action::Record must be subclassed to be used");
+    my $class = ref $self;
+    my $hint = $class eq __PACKAGE__ ? "" :
+        " (did you forget to override record_class in $class?)";
+    $self->log->fatal("Jifty::Action::Record must be subclassed to be used" .
+        $hint);
 }
 
 =head2 new PARAMHASH
@@ -117,7 +120,7 @@ with the value to be validated, canonicalized, or autocompleted.
 C<validate_FIELD> should return a (success boolean, message) list.
 
 C<autocomplete_FIELD> should return a the same kind of list as
-L<Jifty::Action::_autocomplete_argument/Jifty::Action/_autocomplete_argument>
+L<Jifty::Action::_autocomplete_argument|Jifty::Action/_autocomplete_argument>
 
 C<canonicalized_FIELD> should return the canonicalized value.
 
@@ -128,7 +131,6 @@ sub arguments {
 
     return $self->_cached_arguments if $self->_cached_arguments;
 
-
         my $field_info = {};
 
         my @fields = $self->possible_fields;
@@ -172,9 +174,8 @@ sub arguments {
                 my $same = sub {
                     my ( $self, $value ) = @_;
                     if ( $value ne $self->argument_value($field) ) {
-                        return $self->validation_error( $field
-                                . '_confirm' =>
-                                "The passwords you typed didn't match each other."
+                        return $self->validation_error(
+                            ($field.'_confirm') => _("The passwords you typed didn't match each other")
                         );
                     } else {
                         return $self->validation_ok( $field . '_confirm' );
@@ -242,14 +243,14 @@ sub arguments {
                         }
                         return (
                             $self->validation_error(
-                                $field => $message
-                                    || q{That doesn't look right, but I don't know why}
+                                $field => ($message || _("That doesn't look right, but I don't know why"))
                             )
                         );
                     }
                 };
             }
             my $autocomplete_method = "autocomplete_" . $field;
+
             if ( $self->record->can($autocomplete_method) ) {
                 $info->{'autocompleter'} ||= sub {
                     my ( $self, $value ) = @_;
@@ -260,6 +261,32 @@ sub arguments {
                         %columns );
                 };
             }
+            elsif ($column->autocompleted) {
+                # Auto-generated autocompleter
+                $info->{'autocompleter'} ||= sub {
+                    my ( $self, $value ) = @_;
+
+                    my $collection = Jifty::Collection->new(
+                        record_class => $self->record_class,
+                        current_user => $self->record->current_user
+                    );
+
+                    $collection->unlimit;
+                    $collection->rows_per_page(20);
+                    $collection->limit(column => $field, value => $value, operator => 'STARTSWITH', entry_aggregator => 'AND') if length($value);
+                    $collection->limit(column => $field, value => 'NULL', operator => 'IS NOT', entry_aggregator => 'AND');
+                    $collection->limit(column => $field, value => '', operator => '!=', entry_aggregator => 'AND');
+                    $collection->columns('id', $field);
+                    $collection->order_by(column => $field);
+                    $collection->group_by(column => $field);
+
+                    my @choices;
+                    while (my $record = $collection->next) {
+                        push @choices, $record->$field;
+                    }
+                    return @choices;
+                };
+            }
 
             my $canonicalize_method = "canonicalize_" . $field;
             if ( $self->record->can($canonicalize_method) ) {
@@ -283,7 +310,28 @@ sub arguments {
             $field_info->{$field} = $info;
         }
 
-    $self->_cached_arguments($field_info);
+    if ($self->can('PARAMS')) {
+        # User-defined declarative schema fields can override default ones here
+        my $params = $self->PARAMS;
+
+        # We really, really want our sort_order to prevail over user-defined ones
+        # (as opposed to all other param fields).  So we do exactly that here.
+        while (my ($key, $param) = each %$params) {
+            defined(my $sort_order = $param->sort_order) or next;
+
+            # The .99 below means that it's autogenerated by Jifty::Param::Schema.
+            if ($sort_order =~ /\.99$/) {
+                $param->sort_order($field_info->{$key}{sort_order});
+            }
+        }
+
+        use Jifty::Param::Schema ();
+        $self->_cached_arguments(Jifty::Param::Schema::merge_params($field_info, $params));
+    }
+    else {
+        $self->_cached_arguments($field_info);
+    }
+
     return $self->_cached_arguments();
 }
 
@@ -313,6 +361,32 @@ sub take_action {
     );
 }
 
+sub _setup_event_before_action {
+    my $self = shift;
+
+    my $event_info = {};
+    $event_info->{as_hash_before} = $self->record->as_hash;
+    $event_info->{record_id} = $self->record->id;
+    $event_info->{record_class} = ref($self->record);
+    $event_info->{action_class} = ref($self);
+    $event_info->{action_arguments} = $self->argument_values; # XXX does this work?
+    $event_info->{current_user_id} = $self->current_user->id || 0;
+    return ($event_info);
+}
+
+sub _setup_event_after_action {
+    my $self = shift;
+    my $event_info = shift;
+    $event_info->{result} = $self->result;    
+    $event_info->{timestamp} = time(); 
+    $event_info->{as_hash_after} = $self->record->as_hash;
+
+    my $event_class = $event_info->{'record_class'};
+    $event_class =~ s/::Model::/::Event::Model::/g;
+    Jifty::Util->require($event_class);
+    $event_class->new($event_info)->publish;
+}
+
 =head1 SEE ALSO
 
 L<Jifty::Action>, L<Jifty::Record>, L<Jifty::DBI::Record>,
