@@ -5,17 +5,18 @@ package Jifty::DateTime;
 
 =head1 NAME
 
-Jifty::DateTime - a DateTime subclass that knows about Jifty users 
+Jifty::DateTime - a DateTime subclass that knows about Jifty users
+
 
 =head1 DESCRIPTION
 
 Jifty natively stores timestamps in the database in GMT.  Dates are stored
-without timezone. This class loads and parses dates and sets them 
+without timezone. This class loads and parses dates and sets them
 into the proper timezone.
 
 =cut
 
-use base qw'Jifty::Object DateTime';
+use base qw(Jifty::Object DateTime);
 
 use Date::Manip ();
 
@@ -35,7 +36,7 @@ sub new {
     # Unless the user has explicitly said they want a floating time,
     # we want to convert to the end-user's timezone.  This is
     # complicated by the fact that DateTime auto-appends
-    if (my $tz = $self->current_user_has_timezone) {
+    if (!$args{time_zone} and my $tz = $self->current_user_has_timezone) {
         $self->set_time_zone("UTC");
         $self->set_time_zone( $tz );
     }
@@ -69,6 +70,7 @@ sub new_from_string {
     my $class  = shift;
     my $string = shift;
     my $now;
+
     {
         # Date::Manip interprets days of the week (eg, ''monday'') as
         # days within the *current* week. Detect these and prepend
@@ -77,7 +79,10 @@ sub new_from_string {
         if($string =~ /^\s* (?:monday|tuesday|wednesday|thursday|friday|saturday|sunday)$/xi) {
             $string = "next $string";
         }
-        local $ENV{'TZ'} = "GMT";
+        
+        # Why are we parsing this as GMT? This feels really wrong.  It will get the wrong answer
+        # if the current user is in another tz.
+        Date::Manip::Date_Init("TZ=GMT");
         $now = Date::Manip::UnixDate( $string, "%o" );
     }
     return undef unless $now;
