@@ -80,7 +80,7 @@ for the user who has the email address I<ADDRESS>.
 sub _user_from_email {
     my $self = shift;
     my $email = shift;
-    my $currentuser_object_class = Jifty->config->framework('ApplicationClass')."::CurrentUser";
+    my $currentuser_object_class = Jifty->app_class("CurrentUser");
     return $currentuser_object_class->new( email => $email );
 }
 
@@ -89,7 +89,10 @@ sub _generate_digest {
 
     # get user's generic secret
     my $user;
-    return undef unless ( $user = $self->_user_from_email($self->email) );
+    return '' unless ( $user = $self->_user_from_email($self->email) );
+    return '' unless ($user->auth_token);
+
+
 
     # build an md5sum of the email token and until and our secret
     my $digest = Digest::MD5->new();
@@ -177,6 +180,9 @@ sub from_token {
     $self->path( shift @atoms );
     $self->checksum_provided( pop @atoms );
 
+    # If they don't even have the right number of items in the path, then we know that it's not valid
+    return undef unless (scalar @atoms % 2 == 0); 
+
     my %args = map { Jifty::I18N->maybe_decode_utf8(URI::Escape::uri_unescape($_)) } @atoms;
     $self->until( delete $args{until} ) if $args{until};
 
