@@ -29,6 +29,9 @@ C<current_user>, and so on up the call stack.
 
 sub current_user {
     my $self = shift;
+    unless (ref($self)) {
+        Carp::cluck("Called current_user as a class method. Dealing. Fix your code.");
+    }
     $self->{'_current_user'} = shift if (@_); 
     return($self->{'_current_user'});
 }
@@ -36,9 +39,9 @@ sub current_user {
 =head2 PRIVATE _get_current_user
 
 Takes the ARGS paramhash passed to _init.
-     Find the current user. First, try to see if it's explicit.
-     After that, check the caller's current_user. After that, look
-     at Jifty->web->current_user
+Find the current user. First, try to see if it's explicit.
+After that, check the caller's current_user. After that, look
+at Jifty->web->current_user
 
 Fills in current_user with that value
 
@@ -49,7 +52,7 @@ sub _get_current_user {
     my $self = shift;
     my %args = (@_);
 
-    return if ( $self->current_user );
+    return if ( ref($self) && $self->current_user );
 
     if ( $args{'current_user'} ) {
         return $self->current_user( $args{'current_user'} );
