@@ -6,7 +6,7 @@ Jifty::Param::Schema - Declare parameters of a Jifty action with ease.
 
 =head1 SYNOPSIS
 
-    package Wifty::Action::Login;
+    package MyApp::Action::Login;
     use Jifty::Param::Schema;
     use Jifty::Action schema {
 
@@ -88,6 +88,7 @@ use Object::Declare (
         valid       => 'valid_values',
         render      => 'render_as',
         order       => 'sort_order',
+        max_length  => 'length',
     },
     copula  => {
         is      => '',
@@ -110,22 +111,65 @@ sub schema (&) {
 
     Class::Data::Inheritable::mk_classdata($from => qw/PARAMS/);
     my @params = &declare($code);
-    my $count = 1; # Start at 1, increment by 10
+
+    # The .99 here is a flag for Jifty::Action::Record to mark autogenerated orders
+    my $count = 10000.99;
     foreach my $param (@params) {
         next if !ref($param) or defined($param->sort_order);
         $param->sort_order($count);
         $count += 10;
     }
 
-    if ($from->can('SUPER::PARAMS')) {
-        unshift @params, %{ $from->can('SUPER::PARAMS')->() || {} }
+    if (my $super_params = $from->can('SUPER::PARAMS')) {
+        $from->PARAMS(merge_params( $super_params->(), { @params } ));
+    }
+    else {
+        $from->PARAMS({ @params });
     }
-
-    $from->PARAMS({ @params });
 
     no strict 'refs';
     push @{$from . '::ISA'}, 'Jifty::Action';
     return;
 }
 
+use Hash::Merge ();
+
+no warnings 'uninitialized';
+use constant MERGE_PARAM_BEHAVIOUR => {
+    SCALAR => {
+            SCALAR => sub { length($_[1]) ? $_[1] : $_[0] },
+            ARRAY  => sub { [ @{$_[1]} ] },
+            HASH   => sub { $_[1] } },
+    ARRAY => {
+            SCALAR => sub { length($_[1]) ? $_[1] : $_[0] },
+            ARRAY  => sub { [ @{$_[1]} ] },
+            HASH   => sub { $_[1] } },
+    HASH => {
+            SCALAR => sub { length($_[1]) ? $_[1] : $_[0] },
+            ARRAY  => sub { [ @{$_[1]} ] },
+            HASH   => sub { Hash::Merge::_merge_hashes( $_[0], $_[1] ) } }
+};
+
+=head2 merge_params HASHREF HASHREF
+
+Takes two hashrefs. Merges them together and returns the merged hashref.
+
+    - Empty fields in subclasses don't override nonempty fields in superclass anymore.
+    - Arrays don't merge; e.g. if parent class's valid_values is [1,2,3,4], and
+      subclass's valid_values() is [1,2], they don't somehow become [1,2,3,4,1,2].
+
+BUG: This should either be a private routine or factored out into Jifty::Util
+
+
+
+=cut
+
+sub merge_params {
+    my $prev_behaviour = Hash::Merge::get_behavior();
+    Hash::Merge::specify_behavior( MERGE_PARAM_BEHAVIOUR, "merge_params" );
+    my $rv = Hash::Merge::merge(@_);
+    Hash::Merge::set_behavior( $prev_behaviour );
+    return $rv;
+}
+
 1;
