@@ -6,6 +6,19 @@ package Jifty::Web::Form::Field::Button;
 use base qw/Jifty::Web::Form::Field/;
 __PACKAGE__->mk_accessors(qw/button_as_link/);
 
+
+=head1 NAME
+
+Jifty::Web::Form::Field::Button
+
+=cut
+
+=head1 SUMMARY
+
+L<Jifty::Web::Form::Field::Button/> is a L<Jifty::Web::Form::Field>
+
+=head1 METHODS
+
 =head2 accessors
 
 Provide the C<button_as_link> accessor (in addition to
@@ -31,6 +44,7 @@ sub render_widget {
         'name="' . $self->input_name . '" ',
         'value="' . _($self->label ). '"',
         'id="'. Jifty->web->serial . '"',
+        ($self->key_binding ? qq( accesskey="@{[$self->key_binding]}") : ''),
         $self->_widget_class('button', ($self->button_as_link ? ("button_as_link") : ())),
         $self->javascript,
         ' />',
