@@ -39,9 +39,9 @@ sub arguments {
         password_confirm => 1,
     );
 
-    for ( keys %$args ) { delete $args->{$_} unless ( $fields{$_} ); }
     $args->{'email'}{'ajax_validates'}   = 1;
-    $args->{'password_confirm'}{'label'} = "Type that again?";
+    $args->{'password_confirm'}{'label'} = _("Type that again?");
+    $args->{'name'}{'label'} = _("Name");
     return $args;
 }
 
@@ -54,18 +54,18 @@ Make sure their email address looks sane
 sub validate_email {
     my $self  = shift;
     my $email = shift;
-    my $LoginUser = $self->LoginUserClass();
-    my $CurrentUser = $self->CurrentUserClass();
+    my $LoginUserClass = $self->LoginUserClass;
+    my $CurrentUser = $self->CurrentUserClass;
 
     return $self->validation_error(
-        email => "That doesn't look like an email address." )
+        email => _("That doesn't look like an email address.") )
       unless ( $email =~ /\S\@\S/ );
 
-    my $u = $LoginUser->new( current_user => $CurrentUser->superuser );
+    my $u = $LoginUserClass->new( current_user => $CurrentUser->superuser );
     $u->load_by_cols( email => $email );
     if ( $u->id ) {
         return $self->validation_error( email =>
-'It looks like you already have an account. Perhaps you want to <a href="/login">sign in</a> instead?'
+_('It looks like you already have an account. Perhaps you want to <a href="/login">sign in</a> instead?')
         );
     }
 
@@ -84,9 +84,9 @@ Makes sure that the user only specifies things we want them to.
 
 sub take_action {
     my $self   = shift;
-    my $LoginUser = $self->LoginUserClass();
-    my $CurrentUser = $self->CurrentUserClass();
-    my $record = $LoginUser->new( current_user => $CurrentUser->superuser );
+    my $LoginUserClass = $self->LoginUserClass;
+    my $CurrentUser = $self->CurrentUserClass;
+    my $record = $LoginUserClass->new( current_user => $CurrentUser->superuser );
 
     my %values;
     $values{$_} = $self->argument_value($_) for grep {
@@ -98,15 +98,15 @@ sub take_action {
     # Handle errors?
     unless ( $record->id ) {
         $self->result->error(
-"Something bad happened and we couldn't create your account.  Try again later. We're really, really sorry."
+_("Something bad happened and we couldn't create your account.  Try again later. We're really, really sorry.")
         );
         return;
     }
 
-    $self->result->message( "Welcome to "
+    $self->result->message( _("Welcome to ")
           . Jifty->config->framework('ApplicationName') . ", "
           . $record->name
-          . ". We've sent a confirmation message to your email box." );
+          . _(". We've sent a confirmation message to your email box.") );
 
     return 1;
 }
